* Output options: all can be turned on/off by adding/ removing the NO;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=MAX NOfmterr;
* Remove default title, turn on new HTML graphics;
  TITLE; ODS GRAPHICS ON; 

********************************************************************************;
*******    FIRST DEFINE "FILESAVE" PLACEHOLDER FOR FOLDER LOCATION       *******;
*******          BEGIN EXAMPLE 2 DATA IMPORT AND MANIPULATION            *******;  
********************************************************************************;

* Define global variable for file location to be replaced in code below;
* \\Client\ precedes path in Virtual Desktop outside H drive;
%LET filesave= C:\Dropbox\22SP_PSQF6243\PSQF6243_Example2;
* Using UIowa virtual desktop instead;
*%LET filesave= \\Client\C:\Dropbox\22SP_PSQF6243\PSQF6243_Example2;

* IMPORT GSS_Example.xlsx data using filesave reference and exact file name;
* from the Excel workbook in DATAFILE= location from SHEET= ;
* New SAS file is in "work" library place with name "Example2";
* "GETNAMES" reads in the first row as variable names;
* DBMS=XLSX (can also use EXCEL or XLS for .xls files);
PROC IMPORT DATAFILE="&filesave.\GSS_Example.xlsx" 
            OUT=work.Example2 DBMS=XLSX REPLACE; 
     SHEET="GSS_Example"; 
     GETNAMES=YES; 
RUN;

* DATA = create new dataset, SET = from OLD dataset;
* So DATA + SET means "save as itself" after these actions;
* All data transformations must happen inside a DATA+SET+RUN combo;
DATA work.Example2; SET work.Example2;
* Label variables and apply value formats for variables used below;
* LABEL name=   "name: Descriptive Variable Label";
  LABEL marry=  "marry: Marital Status (1=unmarried, 2=married)"
        educ=   "educ: Years of Education"
        income= "income: Annual Income in 1000s";
* Select cases complete on variables to be used;
  IF NMISS(income,educ,marry)>0 THEN DELETE;
RUN;
* Now dataset work.Example2 is ready to use; 

* Example of sorting to find specific case for slides;
PROC SORT DATA=work.Example2; BY educ income; RUN;

* Open external file to save results to;
ODS RTF FILE="&filesave.\Example2_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;


******************************************************************************;
*******            BEGIN EXAMPLE 2 DATA DESCRIPTION                    *******;
******************************************************************************;

TITLE "SAS Descriptive Statistics for Quantitative or Binary Variables";
PROC MEANS NDEC=3 N MEAN STDDEV VAR MIN MAX DATA=work.Example2; 
     VAR income educ marry;
RUN; TITLE;


******************************************************************************;
*******             BEGIN EXAMPLE 2 GENERAL LINEAR MODELS              *******;
******************************************************************************;

TITLE "SAS Empty GLM Predicting Income";
PROC GLM DATA=work.Example2 NAMELEN=100; * CLPARM gives CI at 1-alpha;
     MODEL income = / SOLUTION ALPHA=.05 CLPARM SS3;
RUN; QUIT; TITLE;


******* MODELS WITH QUANTITATIVE EDUCATION AS A PREDICTOR *******;

TITLE "SAS GLM Predicting Income from Original Education";
PROC GLM DATA=work.Example2 NAMELEN=100; 
     MODEL income = educ / SOLUTION ALPHA=.05 CLPARM SS3;
RUN; QUIT; TITLE;

/*
TITLE "SAS Scatterplot with a regression line to show the regression slope";
PROC SGPLOT DATA=work.Example2;
     SCATTER x=educ y=income;
     REG     x=educ y=income;
     XAXIS LABEL="Years of Education" VALUES=(0 TO 20 BY 2);
     YAXIS LABEL="1000s of Income" VALUES=(-20 TO 70 BY 10);
RUN;
*/

* Center education predictor so that 0 is meaningful;
DATA work.Example2; SET work.Example2;
     educ12=educ-12; 
     LABEL educ12= "educ12: Education (0=12 years)";
RUN;

TITLE "SAS GLM Predicting Income from Centered Education (0=12)";
PROC GLM DATA=work.Example2 NAMELEN=100; 
     MODEL income = educ12 / SOLUTION ALPHA=.05 CLPARM SS3;
* In SAS ESTIMATEs below, words refer to the estimated beta fixed effect,
  and values are the multiplier for the requested predictor value;
     ESTIMATE "Pred Income for  8 years (educ12=-4)" intercept 1 educ12 -4;
     ESTIMATE "Pred Income for 12 years (educ12= 0)" intercept 1 educ12  0;
     ESTIMATE "Pred Income for 16 years (educ12= 4)" intercept 1 educ12  4;
     ESTIMATE "Pred Income for 20 years (educ12= 8)" intercept 1 educ12  8;
RUN; QUIT; TITLE;

/*
TITLE "SAS Scatterplot with a regression line to show the regression";
PROC SGPLOT DATA=work.Example2;
     SCATTER x=educ12 y=income;
     REG     x=educ12 y=income;
     XAXIS LABEL="Education (0=12 Years)" VALUES=(-8 TO 8 BY 2);
     YAXIS LABEL="1000s of Income" VALUES=(-20 TO 70 BY 10);
* Prediction from empty model;
     REFLINE 17.30 / AXIS=Y LINEATTRS=(COLOR=PURPLE THICKNESS=1); 
RUN;
*/

TITLE1 "SAS GLM Predicting Income from Centered Education";
TITLE2 "Using REG instead of GLM to get standardized Effects";
PROC REG DATA=work.Example2; 
     MODEL income = educ12 / STB; * STB option gives standardized solution;
RUN; QUIT; TITLE1; TITLE2;


******* MODELS WITH BINARY MARITAL STATUS AS A PREDICTOR *******;

* Recode marry predictor so that 0 is meaningful;
DATA work.Example2; SET work.Example2;
     marry01=.; * Create new empty variable, then recode;
     IF marry=1 THEN marry01=0;
     IF marry=2 THEN marry01=1;
     LABEL marry01= "marry01: 0=unmarried, 1=married";
RUN;

TITLE "SAS GLM Predicting Income from Marry01 (0=Unmarried,1=Married)";
PROC GLM DATA=work.Example2 NAMELEN=100; 
     MODEL income = marry01 / SOLUTION ALPHA=.05 CLPARM;
* ESTIMATEs below request predicted outcome means for each category; 
     ESTIMATE "Pred Income for Unmarried=0" intercept 1 marry01 0; * Beta0;
     ESTIMATE "Pred Income for Married=1"   intercept 1 marry01 1; * Beta0+Beta1;
RUN; QUIT; TITLE;

* Compute d effect size for marry01 from t test-statistic;
DATA work.MakeD; 
     CohenD=2*6.25/SQRT(732);
RUN;
TITLE "SAS Print result for Cohen d";
PROC PRINT NOOBS DATA=work.MakeD;
RUN;

******************************************************************************;
*******             BEGIN EXAMPLE 2 PEARSON CORRELATIONS               *******;
******************************************************************************;

TITLE "SAS Pearson Correlations and CIs";
PROC CORR NOSIMPLE DATA=work.Example2 PEARSON FISHER(BIASADJ=NO ALPHA=.05);
     VAR income educ marry;
RUN; TITLE;

* Close external output file;
ODS RTF CLOSE;
